subjects

# XMLRésuméLibrary: User Guide

subject | Element Reference | suburb

## Name

subjects — A group of one or more subjects

## Synopsis

### Content Model

    (subject+)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `subjects` element contains one or more `subject`s that were studied as part of the `degree` represented by the parent of the `subjects`.

### Parents

`subjects` may be contained in these elements: `degree`

## Examples

    <subjects>
      <subject>
        <title>Chemistry</title>
        <result>C</result>
      </subject>
      <subject>
        <title>Physics</title>
        <result>B-</result>
      </subject>
    </subjects>

subject | Element Reference | suburb